@@ -19,7 +19,7 @@
 # SOFTWARE.
 """This module provides an interface to the GazeBase dataset."""
 from pymovements.base import Experiment
-from pymovements.datasets.base import PublicDataset
+from pymovements.datasets.public_dataset import PublicDataset
 
 
 class GazeBase(PublicDataset):
@@ -38,6 +38,16 @@ class GazeBase(PublicDataset):
     task (BLG).
 
     Check the respective paper for details :cite:p:`GazeBase`.
+
+    Change to ``download=True`` and `extract=True`` for downloading and extracting the dataset.
+
+    >>> dataset = GazeBase(
+    ...     root='data/',
+    ...     download=False,
+    ...     extract=False,
+    ...     remove_finished=False,
+    ... )
+    >>> dataset.load()  # doctest: +SKIP
     """
     _mirrors = [
         'https://figshare.com/ndownloader/files/',
