@@ -25,6 +25,8 @@ from __future__ import annotations
 import numpy as np
 import polars as pl
 
+from pymovements.utils.checks import check_shapes_positions_velocities
+
 
 def dispersion(positions: list[list[float]] | np.ndarray) -> float:
     """
@@ -47,7 +49,8 @@ def dispersion(positions: list[list[float]] | np.ndarray) -> float:
 
 
 def idt(
-        positions: list[list[float]] | np.ndarray,
+        positions: list[list[float]] | list[tuple[float, float]] | np.ndarray,
+        velocities: list[list[float]] | list[tuple[float, float]] | np.ndarray,
         dispersion_threshold: float,
         minimum_duration: int,
 ) -> pl.DataFrame:
@@ -67,6 +70,8 @@ def idt(
     ----------
     positions: array-like, shape (N, 2)
         Continuous 2D position time series
+    velocities: array-like, shape (N, 2)
+        Corresponding continuous 2D velocity time series.
     dispersion_threshold: float
         Threshold for dispersion for a group of consecutive samples to be identified as fixation
     minimum_duration: int
@@ -84,24 +89,14 @@ def idt(
         If dispersion_threshold is not greater than 0
         If duration_threshold is not greater than 0
     """
-
     positions = np.array(positions)
+    velocities = np.array(velocities)
 
-    # make sure positions is 2d
-    if positions.ndim != 2:
-        raise ValueError('positions needs to have shape (N, 2)')
-
-    # make sure positions has shape (N, 2)
-    if positions.shape[1] != 2:
-        raise ValueError('positions needs to have shape (N, 2)')
-
-    # Check if dispersion_threshold is greater 0
+    check_shapes_positions_velocities(positions=positions, velocities=velocities)
     if dispersion_threshold <= 0:
         raise ValueError('dispersion threshold must be greater than 0')
-
-    # Check if duration_threshold is greater 0
     if minimum_duration <= 0:
-        raise ValueError('duration threshold must be greater than 0')
+        raise ValueError('minimum duration must be greater than 0')
 
     fixations = []
 
@@ -116,16 +111,16 @@ def idt(
                 win_end += 1
 
                 # break if we reach end of input data
-                if win_end == len(positions) - 1:
+                if win_end == len(positions):
                     break
 
             # Note a fixation at the centroid of the window points
-            centroid = np.mean(positions[win_start:win_end], axis=0)
+            centroid = np.mean(positions[win_start:win_end - 1], axis=0)
 
             fixations.append({
                 'type': 'fixation',
                 'onset': win_start,
-                'offset': win_end,
+                'offset': win_end - 1,
                 'position': centroid.tolist(),
             })
 
